@@ -1,7 +1,7 @@
 BootAfterBootT.PI <-
 function(x,p,h,nboot,prob)
 {
-#set.seed(12345)
+set.seed(12345)
 n <- nrow(x)
 
 B <- OLS.ART(x,p,h,prob)
