@@ -11,8 +11,8 @@ function(x,p,h,prob)
     {
     f <- AR.Fore(x,b,h)
     s2 <- sum(e^2)/(nrow(x)-length(b))
-    mf <- mainf(b,h,p)
-    se <- as.matrix(sqrt(s2*cumsum(mf[1:h]^2)))
+    mf <- mainf(b,h-1,p)
+    se <- as.matrix(sqrt(s2*cumsum(mf^2)))
 
     PImat <- matrix(NA,ncol=length(prob),nrow=h)
     for( i in 1:length(prob))
